@@ -60,7 +60,6 @@ import java.util.Date;
 import java.util.List;
 import javax.mail.MessagingException;
 import javax.mail.internet.InternetAddress;
-import org.apache.commons.logging.Log;
 import com.openexchange.exception.OXException;
 import com.openexchange.imap.config.IMAPConfig;
 import com.openexchange.imap.util.ImapUtility;
@@ -97,12 +96,7 @@ public final class AllFetch {
     /**
      * The logger constant.
      */
-    protected static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(com.openexchange.log.LogFactory.getLog(AllFetch.class));
-
-    /**
-     * Whether debug logging is enabled.
-     */
-    protected static final boolean DEBUG = LOG.isDebugEnabled();
+    protected static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(AllFetch.class);
 
     /**
      * Initializes a new {@link AllFetch}.
@@ -122,7 +116,7 @@ public final class AllFetch {
          * @throws MessagingException If a messaging error occurs
          * @throws OXException If a mail error occurs
          */
-        public abstract void handleItem(final Item item, final MailMessage m, final org.apache.commons.logging.Log logger) throws OXException;
+        public abstract void handleItem(final Item item, final MailMessage m, final org.slf4j.Logger logger) throws OXException;
     }
 
     /**
@@ -135,7 +129,7 @@ public final class AllFetch {
         INTERNALDATE("INTERNALDATE", INTERNALDATE.class, new FetchItemHandler() {
 
             @Override
-            public void handleItem(final Item item, final MailMessage m, final Log logger) {
+            public void handleItem(final Item item, final MailMessage m, final org.slf4j.Logger logger) {
                 m.setReceivedDate(((INTERNALDATE) item).getDate());
             }
         }),
@@ -145,7 +139,7 @@ public final class AllFetch {
         UID("UID", UID.class, new FetchItemHandler() {
 
             @Override
-            public void handleItem(final Item item, final MailMessage m, final Log logger) {
+            public void handleItem(final Item item, final MailMessage m, final org.slf4j.Logger logger) {
                 m.setMailId(Long.toString(((UID) item).uid));
             }
         }),
@@ -155,7 +149,7 @@ public final class AllFetch {
         FLAGS("FLAGS", FLAGS.class, new FetchItemHandler() {
 
             @Override
-            public void handleItem(final Item item, final MailMessage m, final Log logger) throws OXException {
+            public void handleItem(final Item item, final MailMessage m, final org.slf4j.Logger logger) throws OXException {
                 MimeMessageConverter.parseFlags((FLAGS) item, m);
             }
         }),
@@ -165,7 +159,7 @@ public final class AllFetch {
         BODYSTRUCTURE("BODYSTRUCTURE", BODYSTRUCTURE.class, new FetchItemHandler() {
 
             @Override
-            public void handleItem(final Item item, final MailMessage m, final Log logger) throws OXException {
+            public void handleItem(final Item item, final MailMessage m, final org.slf4j.Logger logger) throws OXException {
                 final BODYSTRUCTURE bs = (BODYSTRUCTURE) item;
                 final com.openexchange.java.StringAllocator sb = new com.openexchange.java.StringAllocator();
                 sb.append(bs.type).append('/').append(bs.subtype);
@@ -175,9 +169,7 @@ public final class AllFetch {
                 try {
                     m.setContentType(new ContentType(sb.toString()));
                 } catch (final OXException e) {
-                    if (logger.isWarnEnabled()) {
-                        logger.warn(e.getMessage(), e);
-                    }
+                    logger.warn("", e);
                     m.setContentType(new ContentType(MimeTypes.MIME_DEFAULT));
                 }
                 m.setHasAttachment(bs.isMulti() && ("MIXED".equalsIgnoreCase(bs.subtype) || MimeMessageUtility.hasAttachments(bs)));
@@ -189,7 +181,7 @@ public final class AllFetch {
         SIZE("RFC822.SIZE", RFC822SIZE.class, new FetchItemHandler() {
 
             @Override
-            public void handleItem(final Item item, final MailMessage m, final Log logger) {
+            public void handleItem(final Item item, final MailMessage m, final org.slf4j.Logger logger) {
                 m.setSize(((RFC822SIZE) item).size);
             }
         }),
@@ -201,7 +193,7 @@ public final class AllFetch {
         ENVELOPE("ENVELOPE", ENVELOPE.class, new FetchItemHandler() {
 
             @Override
-            public void handleItem(final Item item, final MailMessage m, final Log logger) {
+            public void handleItem(final Item item, final MailMessage m, final org.slf4j.Logger logger) {
                 final com.sun.mail.imap.protocol.ENVELOPE envelope = (ENVELOPE) item;
                 // Date
                 m.setSentDate(envelope.date);
@@ -359,7 +351,7 @@ public final class AllFetch {
                                     try {
                                         lowCostItem.getItemHandler().handleItem(item, m, LOG);
                                     } catch (final OXException e) {
-                                        LOG.error(e.getMessage(), e);
+                                        LOG.error("", e);
                                     }
                                 }
                                 l.add(m);
@@ -387,7 +379,7 @@ public final class AllFetch {
                             return new MailMessage[0];
                         }
                     } catch (final MessagingException e) {
-                        LOG.warn("STATUS command failed. Throwing original exception: " + response.toString(), e);
+                        LOG.warn("STATUS command failed. Throwing original exception: {}", response, e);
                     }
                     throw new CommandFailedException(IMAPException.getFormattedMessage(
                         IMAPException.Code.PROTOCOL_ERROR,
@@ -434,15 +426,15 @@ public final class AllFetch {
                 }
             }
         } catch (final SecurityException e) {
-            LOG.error(e.getMessage(), e);
+            LOG.error("", e);
         } catch (final IllegalArgumentException e) {
-            LOG.error(e.getMessage(), e);
+            LOG.error("", e);
         } catch (final NoSuchFieldException e) {
-            LOG.error(e.getMessage(), e);
+            LOG.error("", e);
         } catch (final IllegalAccessException e) {
-            LOG.error(e.getMessage(), e);
+            LOG.error("", e);
         } catch (final RuntimeException e) {
-            LOG.error(e.getMessage(), e);
+            LOG.error("", e);
         }
     }
 
@@ -457,15 +449,15 @@ public final class AllFetch {
         try {
             return IMAPTracer.enableTrace(protocol, sbout);
         } catch (final SecurityException e) {
-            LOG.error(e.getMessage(), e);
+            LOG.error("", e);
         } catch (final IllegalArgumentException e) {
-            LOG.error(e.getMessage(), e);
+            LOG.error("", e);
         } catch (final NoSuchFieldException e) {
-            LOG.error(e.getMessage(), e);
+            LOG.error("", e);
         } catch (final IllegalAccessException e) {
-            LOG.error(e.getMessage(), e);
+            LOG.error("", e);
         } catch (final RuntimeException e) {
-            LOG.error(e.getMessage(), e);
+            LOG.error("", e);
         }
         return null;
     }
