@@ -52,7 +52,6 @@ package com.openexchange.imap;
 import java.net.InetAddress;
 import java.net.UnknownHostException;
 import java.util.concurrent.ConcurrentMap;
-import org.apache.commons.logging.Log;
 import org.cliffc.high_scale_lib.NonBlockingHashMap;
 import com.openexchange.exception.OXException;
 import com.openexchange.mail.Protocol;
@@ -64,7 +63,7 @@ import com.openexchange.mail.Protocol;
  */
 public final class IMAPProtocol extends Protocol {
 
-    private static final Log LOG = com.openexchange.log.Log.loggerFor(IMAPProtocol.class);
+    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(IMAPProtocol.class);
 
     private static final long serialVersionUID = 7946276250330261425L;
 
@@ -136,7 +135,7 @@ public final class IMAPProtocol extends Protocol {
         try {
             return (null == concurrentMap.putIfAbsent(InetAddress.getByName(host), Integer.valueOf(maxCount)));
         } catch (final UnknownHostException e) {
-            LOG.warn("Couldn't resolve host name: " + host + ". Assume default max-count setting instead.", e);
+            LOG.warn("Couldn't resolve host name: {}. Assume default max-count setting instead.", host, e);
             return false;
         }
     }
@@ -154,7 +153,7 @@ public final class IMAPProtocol extends Protocol {
         try {
             concurrentMap.remove(InetAddress.getByName(host));
         } catch (final UnknownHostException e) {
-            LOG.warn("Couldn't remove max-count setting for: " + host, e);
+            LOG.warn("Couldn't remove max-count setting for: {}", host, e);
         }
     }
 
@@ -176,7 +175,7 @@ public final class IMAPProtocol extends Protocol {
             final Integer mc = concurrentMap.get(InetAddress.getByName(host));
             return mc == null ? (null == thisMaxCount ? -1 : thisMaxCount.intValue()) : minOf(mc.intValue(), thisMaxCount);
         } catch (final UnknownHostException e) {
-            LOG.warn("Couldn't resolve host name: " + host + ". Return default max-count setting instead.", e);
+            LOG.warn("Couldn't resolve host name: {}. Return default max-count setting instead.", host, e);
             return (null == thisMaxCount ? -1 : thisMaxCount.intValue());
         }
     }
