@@ -73,8 +73,6 @@ import com.openexchange.config.ConfigurationService;
 import com.openexchange.exception.OXException;
 import com.openexchange.imap.IMAPCommandsCollection;
 import com.openexchange.imap.services.Services;
-import com.openexchange.java.StringAllocator;
-import com.openexchange.log.Log;
 import com.openexchange.mail.mime.MimeMailException;
 import com.sun.mail.iap.Argument;
 import com.sun.mail.iap.ProtocolException;
@@ -95,9 +93,7 @@ import com.sun.mail.imap.protocol.IMAPResponse;
  */
 final class ListLsubCollection {
 
-    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(com.openexchange.log.LogFactory.getLog(ListLsubCollection.class));
-
-    private static final boolean DEBUG = LOG.isDebugEnabled();
+    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(ListLsubCollection.class);
 
     private static final String ROOT_FULL_NAME = "";
 
@@ -219,17 +215,7 @@ final class ListLsubCollection {
     public void clear() {
         deprecated.set(true);
         stamp = 0;
-        if (DEBUG) {
-            if (Log.appendTraceToMessage()) {
-                final com.openexchange.java.StringAllocator builder = new com.openexchange.java.StringAllocator("Cleared LIST/LSUB cache.");
-                final String lineSeparator = System.getProperty("line.separator");
-                builder.append(lineSeparator);
-                appendStackTrace(new Throwable().getStackTrace(), builder, lineSeparator);
-                LOG.debug(builder.toString());
-            } else {
-                LOG.debug("Cleared LIST/LSUB cache.", new Throwable());
-            }
-        }
+        LOG.debug("Cleared LIST/LSUB cache.", new Throwable());
     }
 
     /**
@@ -340,7 +326,8 @@ final class ListLsubCollection {
             listMap.clear();
             lsubMap.clear();
         }
-        final long st = DEBUG ? System.currentTimeMillis() : 0L;
+        final boolean debug = LOG.isDebugEnabled();
+        final long st = debug ? System.currentTimeMillis() : 0L;
         /*
          * Perform LIST "" ""
          */
@@ -394,8 +381,8 @@ final class ListLsubCollection {
         /*
          * Debug logs
          */
-        if (DEBUG) {
-            final com.openexchange.java.StringAllocator sb = new com.openexchange.java.StringAllocator(1024);
+        if (debug) {
+            final StringBuilder sb = new StringBuilder(1024);
             {
                 final TreeMap<String, ListLsubEntryImpl> tm = new TreeMap<String, ListLsubEntryImpl>(listMap);
                 sb.append("LIST cache contains after (re-)initialization:\n");
@@ -406,7 +393,7 @@ final class ListLsubCollection {
             }
             {
                 final TreeMap<String, ListLsubEntryImpl> tm = new TreeMap<String, ListLsubEntryImpl>(lsubMap);
-                sb.reinitTo(0);
+                sb.setLength(0);
                 sb.append("LSUB cache contains after (re-)initialization:\n");
                 for (final Entry<String, ListLsubEntryImpl> entry : tm.entrySet()) {
                     sb.append('"').append(entry.getKey()).append("\"=").append(entry.getValue()).append('\n');
@@ -417,7 +404,7 @@ final class ListLsubCollection {
         /*
          * Consistency check
          */
-        checkConsistency();
+        checkConsistency(imapStore);
         /*
          * Status if enabled
          */
@@ -450,7 +437,7 @@ final class ListLsubCollection {
                             }
                         } catch (final Exception e) {
                             // Swallow failed STATUS command
-                            com.openexchange.log.Log.valueOf(com.openexchange.log.LogFactory.getLog(ListLsubCollection.class)).debug(
+                            org.slf4j.LoggerFactory.getLogger(ListLsubCollection.class).debug(
                                 "STATUS command failed for " + imapFolder.getStore().toString(),
                                 e);
                         }
@@ -464,9 +451,9 @@ final class ListLsubCollection {
         if (doGetAcl) {
             initACLs(imapFolder);
         }
-        if (DEBUG) {
+        if (debug) {
             final long dur = System.currentTimeMillis() - st;
-            final com.openexchange.java.StringAllocator sb = new com.openexchange.java.StringAllocator(128);
+            final StringBuilder sb = new StringBuilder(128);
             sb.append("LIST/LSUB cache");
             if (doStatus || doGetAcl) {
                 sb.append(" (");
@@ -498,7 +485,8 @@ final class ListLsubCollection {
         if (!((IMAPStore) imapFolder.getStore()).hasCapability("ACL")) {
             return;
         }
-        final long st = DEBUG ? System.currentTimeMillis() : 0L;
+        final boolean debug = LOG.isDebugEnabled();
+        final long st = debug ? System.currentTimeMillis() : 0L;
         final ConcurrentMap<String, ListLsubEntryImpl> primary;
         final ConcurrentMap<String, ListLsubEntryImpl> lookup;
         if (listMap.size() > lsubMap.size()) {
@@ -527,19 +515,19 @@ final class ListLsubCollection {
                     }
                 } catch (final Exception e) {
                     // Swallow failed ACL command
-                    LOG.debug("ACL/MYRIGHTS command failed for " + imapFolder.getStore().toString(), e);
+                    LOG.debug("ACL/MYRIGHTS command failed for {}", imapFolder.getStore(), e);
                 }
             }
         }
-        if (DEBUG) {
+        if (debug) {
             final long dur = System.currentTimeMillis() - st;
-            final com.openexchange.java.StringAllocator sb = new com.openexchange.java.StringAllocator(64);
+            final StringBuilder sb = new StringBuilder(64);
             sb.append("LIST/LSUB cache built GETACL entries in ").append(dur).append("msec.");
             LOG.debug(sb.toString());
         }
     }
 
-    private void checkConsistency() {
+    private void checkConsistency(final IMAPStore imapStore) {
         final ListLsubEntryImpl rootEntry = listMap.get(ROOT_FULL_NAME);
         /*
          * Ensure every LSUB'ed entry occurs in LIST'ed entries
@@ -554,28 +542,34 @@ final class ListLsubCollection {
                     /*
                      * Either shared or user namespace
                      */
-                    final ListLsubEntryImpl lle = new ListLsubEntryImpl(entry.getValue(), true);
-                    listMap.put(fullName, lle);
-                    /*
-                     * Determine parent
-                     */
-                    final int pos = fullName.lastIndexOf(lle.getSeparator());
-                    if (pos >= 0) {
+                    if (existsSafe(fullName, imapStore)) {
+                        final ListLsubEntryImpl lle = new ListLsubEntryImpl(entry.getValue(), true);
+                        listMap.put(fullName, lle);
                         /*
-                         * Non-root level
+                         * Determine parent
                          */
-                        final String parentFullName = fullName.substring(0, pos);
-                        final ListLsubEntryImpl parent = listMap.get(parentFullName);
-                        {
-                            lle.setParent(parent);
-                            parent.addChild(lle);
+                        final int pos = fullName.lastIndexOf(lle.getSeparator());
+                        if (pos >= 0) {
+                            /*
+                             * Non-root level
+                             */
+                            final String parentFullName = fullName.substring(0, pos);
+                            final ListLsubEntryImpl parent = listMap.get(parentFullName);
+                            {
+                                lle.setParent(parent);
+                                parent.addChild(lle);
+                            }
+                        } else {
+                            /*
+                             * Root level
+                             */
+                            lle.setParent(rootEntry);
+                            rootEntry.addChild(lle);
                         }
                     } else {
-                        /*
-                         * Root level
-                         */
-                        lle.setParent(rootEntry);
-                        rootEntry.addChild(lle);
+                        IMAPCommandsCollection.forceSetSubscribed(imapStore, fullName, false);
+                        final ListLsubEntryImpl lle = entry.getValue();
+                        dropEntryFrom(lle, listMap);
                     }
                 } else {
                     /*
@@ -603,6 +597,16 @@ final class ListLsubCollection {
         }
     }
 
+    private static boolean existsSafe(final String fullName, final IMAPStore imapStore) {
+        try {
+            return imapStore.getFolder(fullName).exists();
+        } catch (final MessagingException e) {
+            // Swallow
+            LOG.debug("Failed checking existence for {}", fullName, e);
+        }
+        return false;
+    }
+
     /**
      * Gets current entry for specified full name.
      *
@@ -716,12 +720,10 @@ final class ListLsubCollection {
          */
         final String command = "LIST";
         final Response[] r;
-        if (DEBUG) {
-            final String sCmd = new StringAllocator(command).append(" (SPECIAL-USE) \"\" \"*\"").toString();
+        {
+            final String sCmd = new StringBuilder(command).append(" (SPECIAL-USE) \"\" \"*\"").toString();
             r = performCommand(protocol, sCmd);
-            LOG.debug((command) + " cache filled with >>" + sCmd + "<< which returned " + r.length + " response line(s).");
-        } else {
-            r = performCommand(protocol, new StringAllocator(command).append(" (SPECIAL-USE) \"\" \"*\"").toString());
+            LOG.debug("{0} cache filled with >>{}<< which returned {} response line(s).", (command), sCmd, r.length);
         }
         final Response response = r[r.length - 1];
         if (response.isOK()) {
@@ -768,16 +770,13 @@ final class ListLsubCollection {
         // Perform command
         final String command = lsub ? "LSUB" : "LIST";
         final Response[] r;
-        if (DEBUG) {
-            final String sCmd = new StringAllocator(command).append(" \"\" \"*\"").toString();
+        {
+            final String sCmd = new StringBuilder(command).append(" \"\" \"*\"").toString();
             r = performCommand(protocol, sCmd);
-            LOG.debug((command) + " cache filled with >>" + sCmd + "<< which returned " + r.length + " response line(s).");
-        } else {
-            r = performCommand(protocol, new StringAllocator(command).append(" \"\" \"*\"").toString(), null);
+            LOG.debug("{} cache filled with >>{1}<< which returned {} response line(s).", (command), sCmd, r.length);
         }
         final Response response = r[r.length - 1];
         if (response.isOK()) {
-            final long st = DEBUG ? System.currentTimeMillis() : -1L;
             final ConcurrentMap<String, ListLsubEntryImpl> map = lsub ? lsubMap : listMap;
             final Map<String, List<ListLsubEntryImpl>> parentMap = new HashMap<String, List<ListLsubEntryImpl>>(4);
             final ListLsubEntryImpl rootEntry = map.get(ROOT_FULL_NAME);
@@ -844,10 +843,6 @@ final class ListLsubCollection {
 
             // Dispatch remaining untagged responses
             protocol.notifyResponseHandlers(r);
-            if (DEBUG) {
-                final long d = System.currentTimeMillis() - st;
-                LOG.debug(command + " cache filled within " + d + "msec.");
-            }
         } else {
             // Dispatch remaining untagged responses
             protocol.notifyResponseHandlers(r);
@@ -1204,7 +1199,7 @@ final class ListLsubCollection {
         String mbox = BASE64MailboxEncoder.encode(fullName);
         Argument args = new Argument();
         args.writeString(mbox);
-        final Response[] r = performCommand(protocol, new StringAllocator(command).append(" \"\"").toString(), args);
+        final Response[] r = performCommand(protocol, new StringBuilder(command).append(" \"\"").toString(), args);
         args = null;
         mbox = null;
         final Response response = r[r.length - 1];
@@ -1251,20 +1246,21 @@ final class ListLsubCollection {
              * Dispatch remaining untagged responses
              */
             protocol.notifyResponseHandlers(r);
-            /*
-             * Debug logs
-             */
-            if (DEBUG) {
-                final TreeMap<String, ListLsubEntryImpl> tm = new TreeMap<String, ListLsubEntryImpl>();
-                tm.putAll(map);
-                final com.openexchange.java.StringAllocator sb = new com.openexchange.java.StringAllocator(1024);
-                sb.append((lsub ? "LSUB" : "LIST") + " cache contains after adding single entry \"");
-                sb.append(fullName).append("\":\n");
-                for (final Entry<String, ListLsubEntryImpl> entry : tm.entrySet()) {
-                    sb.append('"').append(entry.getKey()).append("\"=").append(entry.getValue()).append('\n');
+            LOG.debug("{}", new Object() {
+
+                @Override
+                public String toString() {
+                    final TreeMap<String, ListLsubEntryImpl> tm = new TreeMap<String, ListLsubEntryImpl>();
+                    tm.putAll(map);
+                    final StringBuilder sb = new StringBuilder(1024);
+                    sb.append((lsub ? "LSUB" : "LIST") + " cache contains after adding single entry \"");
+                    sb.append(fullName).append("\":\n");
+                    for (final Entry<String, ListLsubEntryImpl> entry : tm.entrySet()) {
+                        sb.append('"').append(entry.getKey()).append("\"=").append(entry.getValue()).append('\n');
+                    }
+                    return sb.toString();
                 }
-                LOG.debug(sb.toString());
-            }
+            });
             return retval;
         }
         /*
@@ -1300,7 +1296,7 @@ final class ListLsubCollection {
                         }
                     } catch (final Exception e) {
                         // Swallow failed STATUS command
-                        com.openexchange.log.Log.valueOf(com.openexchange.log.LogFactory.getLog(ListLsubCollection.class)).debug(
+                        org.slf4j.LoggerFactory.getLogger(ListLsubCollection.class).debug(
                             "STATUS command failed for " + imapFolder.getStore().toString(),
                             e);
                     }
@@ -1320,7 +1316,7 @@ final class ListLsubCollection {
                         }
                     } catch (final Exception e) {
                         // Swallow failed ACL command
-                        com.openexchange.log.Log.valueOf(com.openexchange.log.LogFactory.getLog(ListLsubCollection.class)).debug(
+                        org.slf4j.LoggerFactory.getLogger(ListLsubCollection.class).debug(
                             "ACL/MYRIGHTS command failed for " + imapFolder.getStore().toString(),
                             e);
                     }
@@ -1445,6 +1441,27 @@ final class ListLsubCollection {
         return lsubMap.get(fullName);
     }
 
+    /**
+     * Gets the LSUB entries.
+     *
+     * @return The LSUB entries
+     */
+    public List<ListLsubEntry> getLsubs() {
+        checkDeprecated();
+        return new ArrayList<ListLsubEntry>(lsubMap.values());
+    }
+
+    /**
+     * Gets the LIST entries.
+     *
+     * @return The LIST entries
+     */
+    public List<ListLsubEntry> getLists() {
+        checkDeprecated();
+        return new ArrayList<ListLsubEntry>(listMap.values());
+    }
+
+
     private static final TObjectIntHashMap<String> POS_MAP;
 
     static {
@@ -2021,7 +2038,7 @@ final class ListLsubCollection {
 
         @Override
         public String toString() {
-            final com.openexchange.java.StringAllocator sb = new com.openexchange.java.StringAllocator(128).append("{ ").append(lsubMap == null ? "LSUB" : "LIST");
+            final StringBuilder sb = new StringBuilder(128).append("{ ").append(lsubMap == null ? "LSUB" : "LIST");
             sb.append(" fullName=\"").append(fullName).append('"');
             sb.append(", parent=");
             if (null == parent) {
@@ -2079,7 +2096,7 @@ final class ListLsubCollection {
 
     } // End of class ListLsubEntryImpl
 
-    private static void appendStackTrace(final StackTraceElement[] trace, final com.openexchange.java.StringAllocator sb, final String lineSeparator) {
+    private static void appendStackTrace(final StackTraceElement[] trace, final StringBuilder sb, final String lineSeparator) {
         if (null == trace) {
             sb.append("<missing stack trace>\n");
             return;
@@ -2121,7 +2138,7 @@ final class ListLsubCollection {
             return INBOX;
         }
         if (fullName.length() > 5 && upperCase.startsWith("INBOX") && separator == upperCase.charAt(5)) {
-            return new StringAllocator(INBOX).append(separator).append(fullName.substring(6)).toString();
+            return new StringBuilder(INBOX).append(separator).append(fullName.substring(6)).toString();
         }
         return fullName;
     }
