@@ -107,9 +107,7 @@ import com.sun.mail.imap.protocol.UID;
  */
 public final class SimpleFetchIMAPCommand extends AbstractIMAPCommand<TLongObjectMap<MailMessage>> {
 
-    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(com.openexchange.log.LogFactory.getLog(SimpleFetchIMAPCommand.class));
-
-    private static final boolean WARN = LOG.isWarnEnabled();
+    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(SimpleFetchIMAPCommand.class);
 
     private static final int LENGTH = 9; // "FETCH <nums> (<command>)"
 
@@ -298,9 +296,7 @@ public final class SimpleFetchIMAPCommand extends AbstractIMAPCommand<TLongObjec
                 if (null == itemHandler) {
                     itemHandler = getItemHandlerByItem(item);
                     if (null == itemHandler) {
-                        if (WARN) {
-                            LOG.warn("Unknown FETCH item: " + item.getClass().getName());
-                        }
+                        LOG.warn("Unknown FETCH item: {}", item.getClass().getName());
                     } else {
                         lastHandlers.add(itemHandler);
                         itemHandler.handleItem(item, mail, LOG);
@@ -320,22 +316,16 @@ public final class SimpleFetchIMAPCommand extends AbstractIMAPCommand<TLongObjec
             /*
              * Discard corrupt message
              */
-            if (WARN) {
+            {
                 final OXException imapExc = MimeMailException.handleMessagingException(e);
-                LOG.warn(
-                    new com.openexchange.java.StringAllocator(128).append("Message #").append(mail.getSeqnum()).append(" discarded: ").append(imapExc.getMessage()).toString(),
-                    imapExc);
+                LOG.warn("Message #{} discarded", mail.getSeqnum(), imapExc);
             }
             error = true;
         } catch (final OXException e) {
             /*
              * Discard corrupt message
              */
-            if (WARN) {
-                LOG.warn(
-                    new com.openexchange.java.StringAllocator(128).append("Message #").append(mail.getSeqnum()).append(" discarded: ").append(e.getMessage()).toString(),
-                    e);
-            }
+            LOG.warn("Message #{} discarded", mail.getSeqnum(), e);
             error = true;
         }
         if (!error) {
@@ -375,9 +365,9 @@ public final class SimpleFetchIMAPCommand extends AbstractIMAPCommand<TLongObjec
          * @throws MessagingException If a messaging error occurs
          * @throws OXException If a mail error occurs
          */
-        void handleItem(final Item item, final IDMailMessage msg, final org.apache.commons.logging.Log logger) throws MessagingException, OXException;
+        void handleItem(final Item item, final IDMailMessage msg, final org.slf4j.Logger logger) throws MessagingException, OXException;
 
-        void handleMessage(final Message message, final IDMailMessage msg, final org.apache.commons.logging.Log logger) throws MessagingException, OXException;
+        void handleMessage(final Message message, final IDMailMessage msg, final org.slf4j.Logger logger) throws MessagingException, OXException;
     }
 
     private static final String MULTI_SUBTYPE_MIXED = "MIXED";
@@ -448,7 +438,7 @@ public final class SimpleFetchIMAPCommand extends AbstractIMAPCommand<TLongObjec
                             try {
                                 mailMessage.setSentDate(mdf.parse(hdr.getValue()));
                             } catch (final ParseException e) {
-                                LOG.error(e.getMessage(), e);
+                                LOG.error("", e);
                             }
                         }
                     }
@@ -476,7 +466,7 @@ public final class SimpleFetchIMAPCommand extends AbstractIMAPCommand<TLongObjec
         };
 
         @Override
-        public void handleItem(final Item item, final IDMailMessage msg, final org.apache.commons.logging.Log logger) throws MessagingException, OXException {
+        public void handleItem(final Item item, final IDMailMessage msg, final org.slf4j.Logger logger) throws MessagingException, OXException {
             final InternetHeaders h;
             {
                 final InputStream headerStream;
@@ -493,10 +483,7 @@ public final class SimpleFetchIMAPCommand extends AbstractIMAPCommand<TLongObjec
                 }
                 h = new InternetHeaders();
                 if (null == headerStream) {
-                    if (logger.isDebugEnabled()) {
-                        logger.debug(new com.openexchange.java.StringAllocator(32).append("Cannot retrieve headers from message #").append(msg.getSeqnum()).append(
-                            " in folder ").append(msg.getFolder()).toString());
-                    }
+                    logger.debug("Cannot retrieve headers from message #{} in folder {}", msg.getSeqnum(), msg.getFolder());
                 } else {
                     h.load(headerStream);
                 }
@@ -513,9 +500,7 @@ public final class SimpleFetchIMAPCommand extends AbstractIMAPCommand<TLongObjec
                 try {
                     msg.addHeader(name, hdr.getValue());
                 } catch (final IllegalArgumentException illegalArgumentExc) {
-                    if (logger.isDebugEnabled()) {
-                        logger.debug("Ignoring invalid header.", illegalArgumentExc);
-                    }
+                    logger.debug("Ignoring invalid header.", illegalArgumentExc);
                 }
                 /*-
                  *
@@ -530,7 +515,7 @@ public final class SimpleFetchIMAPCommand extends AbstractIMAPCommand<TLongObjec
         }
 
         @Override
-        public void handleMessage(final Message message, final IDMailMessage msg, final org.apache.commons.logging.Log logger) throws MessagingException, OXException {
+        public void handleMessage(final Message message, final IDMailMessage msg, final org.slf4j.Logger logger) throws MessagingException, OXException {
             for (final Enumeration<?> e = message.getAllHeaders(); e.hasMoreElements();) {
                 final Header hdr = (Header) e.nextElement();
                 final String name = hdr.getName();
@@ -543,9 +528,7 @@ public final class SimpleFetchIMAPCommand extends AbstractIMAPCommand<TLongObjec
                 try {
                     msg.addHeader(name, hdr.getValue());
                 } catch (final IllegalArgumentException illegalArgumentExc) {
-                    if (logger.isDebugEnabled()) {
-                        logger.debug("Ignoring invalid header.", illegalArgumentExc);
-                    }
+                    logger.debug("Ignoring invalid header.", illegalArgumentExc);
                 }
                 /*-
                  *
@@ -563,7 +546,7 @@ public final class SimpleFetchIMAPCommand extends AbstractIMAPCommand<TLongObjec
     private static final FetchItemHandler FLAGS_ITEM_HANDLER = new FetchItemHandler() {
 
         @Override
-        public void handleItem(final Item item, final IDMailMessage msg, final org.apache.commons.logging.Log logger) throws MessagingException {
+        public void handleItem(final Item item, final IDMailMessage msg, final org.slf4j.Logger logger) throws MessagingException {
             final FLAGS flags = (FLAGS) item;
             /*
              * Parse system flags
@@ -627,7 +610,7 @@ public final class SimpleFetchIMAPCommand extends AbstractIMAPCommand<TLongObjec
         }
 
         @Override
-        public void handleMessage(final Message message, final IDMailMessage msg, final org.apache.commons.logging.Log logger) throws MessagingException {
+        public void handleMessage(final Message message, final IDMailMessage msg, final org.slf4j.Logger logger) throws MessagingException {
             final Flags flags = message.getFlags();
             /*
              * Parse system flags
@@ -694,7 +677,7 @@ public final class SimpleFetchIMAPCommand extends AbstractIMAPCommand<TLongObjec
     private static final FetchItemHandler ENVELOPE_ITEM_HANDLER = new FetchItemHandler() {
 
         @Override
-        public void handleItem(final Item item, final IDMailMessage msg, final org.apache.commons.logging.Log logger) throws MessagingException {
+        public void handleItem(final Item item, final IDMailMessage msg, final org.slf4j.Logger logger) throws MessagingException {
             final ENVELOPE env = (ENVELOPE) item;
             msg.addFrom(env.from);
             msg.addTo(env.to);
@@ -722,7 +705,7 @@ public final class SimpleFetchIMAPCommand extends AbstractIMAPCommand<TLongObjec
         }
 
         @Override
-        public void handleMessage(final Message message, final IDMailMessage msg, final org.apache.commons.logging.Log logger) throws MessagingException {
+        public void handleMessage(final Message message, final IDMailMessage msg, final org.slf4j.Logger logger) throws MessagingException {
             msg.addFrom((InternetAddress[]) message.getFrom());
             msg.addTo((InternetAddress[]) message.getRecipients(RecipientType.TO));
             msg.addCc((InternetAddress[]) message.getRecipients(RecipientType.CC));
@@ -750,12 +733,12 @@ public final class SimpleFetchIMAPCommand extends AbstractIMAPCommand<TLongObjec
     private static final FetchItemHandler INTERNALDATE_ITEM_HANDLER = new FetchItemHandler() {
 
         @Override
-        public void handleItem(final Item item, final IDMailMessage msg, final org.apache.commons.logging.Log logger) {
+        public void handleItem(final Item item, final IDMailMessage msg, final org.slf4j.Logger logger) {
             msg.setReceivedDate(((INTERNALDATE) item).getDate());
         }
 
         @Override
-        public void handleMessage(final Message message, final IDMailMessage msg, final org.apache.commons.logging.Log logger) throws MessagingException {
+        public void handleMessage(final Message message, final IDMailMessage msg, final org.slf4j.Logger logger) throws MessagingException {
             msg.setReceivedDate(message.getReceivedDate());
         }
     };
@@ -763,12 +746,12 @@ public final class SimpleFetchIMAPCommand extends AbstractIMAPCommand<TLongObjec
     private static final FetchItemHandler SIZE_ITEM_HANDLER = new FetchItemHandler() {
 
         @Override
-        public void handleItem(final Item item, final IDMailMessage msg, final org.apache.commons.logging.Log logger) {
+        public void handleItem(final Item item, final IDMailMessage msg, final org.slf4j.Logger logger) {
             msg.setSize(((RFC822SIZE) item).size);
         }
 
         @Override
-        public void handleMessage(final Message message, final IDMailMessage msg, final org.apache.commons.logging.Log logger) throws MessagingException {
+        public void handleMessage(final Message message, final IDMailMessage msg, final org.slf4j.Logger logger) throws MessagingException {
             msg.setSize(message.getSize());
         }
     };
@@ -776,7 +759,7 @@ public final class SimpleFetchIMAPCommand extends AbstractIMAPCommand<TLongObjec
     private static final FetchItemHandler BODYSTRUCTURE_ITEM_HANDLER = new FetchItemHandler() {
 
         @Override
-        public void handleItem(final Item item, final IDMailMessage msg, final org.apache.commons.logging.Log logger) throws OXException {
+        public void handleItem(final Item item, final IDMailMessage msg, final org.slf4j.Logger logger) throws OXException {
             final BODYSTRUCTURE bs = (BODYSTRUCTURE) item;
             final com.openexchange.java.StringAllocator sb = new com.openexchange.java.StringAllocator();
             sb.append(bs.type).append('/').append(bs.subtype);
@@ -788,9 +771,7 @@ public final class SimpleFetchIMAPCommand extends AbstractIMAPCommand<TLongObjec
                 msg.setContentType(new ContentType(contentType));
                 msg.addHeader("Content-Type", contentType);
             } catch (final OXException e) {
-                if (logger.isWarnEnabled()) {
-                    logger.warn(e.getMessage(), e);
-                }
+                logger.warn("", e);
                 msg.setContentType(new ContentType(MimeTypes.MIME_DEFAULT));
                 msg.addHeader("Content-Type", MimeTypes.MIME_DEFAULT);
             }
@@ -798,7 +779,7 @@ public final class SimpleFetchIMAPCommand extends AbstractIMAPCommand<TLongObjec
         }
 
         @Override
-        public void handleMessage(final Message message, final IDMailMessage msg, final org.apache.commons.logging.Log logger) throws MessagingException, OXException {
+        public void handleMessage(final Message message, final IDMailMessage msg, final org.slf4j.Logger logger) throws MessagingException, OXException {
             String contentType;
             try {
                 contentType = message.getContentType();
@@ -828,14 +809,14 @@ public final class SimpleFetchIMAPCommand extends AbstractIMAPCommand<TLongObjec
     private static final FetchItemHandler UID_ITEM_HANDLER = new FetchItemHandler() {
 
         @Override
-        public void handleItem(final Item item, final IDMailMessage msg, final org.apache.commons.logging.Log logger) {
+        public void handleItem(final Item item, final IDMailMessage msg, final org.slf4j.Logger logger) {
             final long id = ((UID) item).uid;
             msg.setMailId(Long.toString(id));
             msg.setUid(id);
         }
 
         @Override
-        public void handleMessage(final Message message, final IDMailMessage msg, final org.apache.commons.logging.Log logger) throws MessagingException {
+        public void handleMessage(final Message message, final IDMailMessage msg, final org.slf4j.Logger logger) throws MessagingException {
             final long id = ((IMAPFolder) message.getFolder()).getUID(message);
             msg.setMailId(Long.toString(id));
             msg.setUid(id);
