@@ -61,6 +61,7 @@ import com.openexchange.exception.OXException;
 import com.openexchange.imap.IMAPProtocol;
 import com.openexchange.imap.entity2acl.Entity2ACL;
 import com.openexchange.imap.services.Services;
+import com.openexchange.java.Strings;
 import com.openexchange.mail.api.AbstractProtocolProperties;
 import com.openexchange.mail.api.IMailProperties;
 import com.openexchange.mail.api.MailConfig.BoolCapVal;
@@ -75,7 +76,7 @@ import com.openexchange.spamhandler.SpamHandler;
  */
 public final class IMAPProperties extends AbstractProtocolProperties implements IIMAPProperties {
 
-    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(com.openexchange.log.LogFactory.getLog(IMAPProperties.class));
+    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(IMAPProperties.class);
 
     private static final IMAPProperties instance = new IMAPProperties();
 
@@ -136,6 +137,10 @@ public final class IMAPProperties extends AbstractProtocolProperties implements
 
     private String sContainerType;
 
+    private String sslProtocols;
+
+    private String cipherSuites;
+
     /**
      * Initializes a new {@link IMAPProperties}
      */
@@ -327,7 +332,7 @@ public final class IMAPProperties extends AbstractProtocolProperties implements
                                         }
                                         sb.append(desc);
                                     } catch (final RuntimeException e) {
-                                        LOG.warn("Max. Number of External Connections: Invalid entry: " + desc, e);
+                                        LOG.warn("Max. Number of External Connections: Invalid entry: {}", desc, e);
                                     }
                                 }
                             }
@@ -381,10 +386,18 @@ public final class IMAPProperties extends AbstractProtocolProperties implements
         spamHandlerName = configuration.getProperty("com.openexchange.imap.spamHandler", SpamHandler.SPAM_HANDLER_FALLBACK).trim();
         logBuilder.append("\tSpam Handler: ").append(spamHandlerName).append('\n');
 
-        logBuilder.append("Global IMAP properties successfully loaded!");
-        if (LOG.isInfoEnabled()) {
-            LOG.info(logBuilder.toString());
+        sslProtocols = configuration.getProperty("com.openexchange.imap.ssl.protocols", "SSLv3 TLSv1").trim();
+        logBuilder.append("\tSupported SSL protocols: ").append(sslProtocols).append("\n");
+
+        {
+            final String tmp = configuration.getProperty("com.openexchange.imap.ssl.ciphersuites", "").trim();
+            this.cipherSuites = Strings.isEmpty(tmp) ? null : tmp;
+            logBuilder.append("\tSupported SSL cipher suites: ").append(null == this.cipherSuites ? "<default>" : cipherSuites).append("\n");
         }
+
+        logBuilder.append("Global IMAP properties successfully loaded!");
+
+        LOG.info(logBuilder.toString());
     }
 
     @Override
@@ -408,6 +421,8 @@ public final class IMAPProperties extends AbstractProtocolProperties implements
         notifyRecent = false;
         notifyFrequencySeconds = 300;
         notifyFullNames = "INBOX";
+        sslProtocols = "SSLv3 TLSv1";
+        cipherSuites = null;
     }
 
     @Override
@@ -591,4 +606,15 @@ public final class IMAPProperties extends AbstractProtocolProperties implements
     public String getsContainerType() {
         return sContainerType;
     }
+
+    @Override
+    public String getSSLProtocols() {
+        return sslProtocols;
+    }
+
+    @Override
+    public String getSSLCipherSuites() {
+        return cipherSuites;
+    }
+
 }
