@@ -87,7 +87,7 @@ import com.openexchange.user.UserService;
  */
 public class SUNMessagingServerEntity2ACL extends Entity2ACL {
 
-    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(com.openexchange.log.LogFactory.getLog(SUNMessagingServerEntity2ACL.class));
+    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(SUNMessagingServerEntity2ACL.class);
 
     private static final SUNMessagingServerEntity2ACL INSTANCE = new SUNMessagingServerEntity2ACL();
 
@@ -171,19 +171,10 @@ public class SUNMessagingServerEntity2ACL extends Entity2ACL {
         Arrays.sort(ids);
         final int pos = Arrays.binarySearch(ids, sessionUser);
         if (pos >= 0) {
-            if (LOG.isWarnEnabled()) {
-                LOG.warn(new StringBuilder().append("Found multiple users with login \"").append(pattern).append(
-                    "\" subscribed to IMAP server \"").append(serverUrl).append("\": ").append(Arrays.toString(ids)).append(
-                    "\nThe session user's ID is returned."));
-            }
+            LOG.warn("Found multiple users with login \"{}\" subscribed to IMAP server \"{}\": {}\nThe session user's ID is returned.", pattern, serverUrl, Arrays.toString(ids));
             return ids[pos];
         }
-        // Just select first user ID
-        if (LOG.isWarnEnabled()) {
-            LOG.warn(new StringBuilder().append("Found multiple users with login \"").append(pattern).append(
-                "\" subscribed to IMAP server \"").append(serverUrl).append("\": ").append(Arrays.toString(ids)).append(
-                "\nThe first found user is returned."));
-        }
+        LOG.warn("Found multiple users with login \"{}\" subscribed to IMAP server \"{}\": {}\nThe first found user is returned.", pattern, serverUrl, Arrays.toString(ids));
         return ids[0];
     }
 
