@@ -61,6 +61,7 @@ import org.osgi.service.event.EventAdmin;
 import org.osgi.service.event.EventConstants;
 import org.osgi.service.event.EventHandler;
 import com.openexchange.caching.CacheService;
+import com.openexchange.caching.events.CacheEventService;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.database.DatabaseService;
 import com.openexchange.imap.IMAPProvider;
@@ -73,15 +74,20 @@ import com.openexchange.imap.storecache.IMAPStoreCache;
 import com.openexchange.imap.threader.ThreadableCache;
 import com.openexchange.imap.threader.ThreadableLoginHandler;
 import com.openexchange.login.LoginHandlerService;
+import com.openexchange.mail.FullnameArgument;
 import com.openexchange.mail.api.MailProvider;
+import com.openexchange.mail.utils.MailFolderUtility;
 import com.openexchange.mailaccount.MailAccountStorageService;
 import com.openexchange.osgi.HousekeepingActivator;
+import com.openexchange.push.PushEventConstants;
 import com.openexchange.secret.osgi.tools.WhiteboardSecretService;
 import com.openexchange.session.Session;
 import com.openexchange.sessiond.SessiondEventConstants;
 import com.openexchange.sessiond.SessiondService;
 import com.openexchange.textxtraction.TextXtractService;
+import com.openexchange.threadpool.AbstractTask;
 import com.openexchange.threadpool.ThreadPoolService;
+import com.openexchange.threadpool.behavior.CallerRunsBehavior;
 import com.openexchange.timer.TimerService;
 import com.openexchange.user.UserService;
 
@@ -92,8 +98,8 @@ import com.openexchange.user.UserService;
  */
 public final class IMAPActivator extends HousekeepingActivator {
 
-    protected static final org.apache.commons.logging.Log LOG =
-        com.openexchange.log.Log.valueOf(com.openexchange.log.LogFactory.getLog(IMAPActivator.class));
+    protected static final org.slf4j.Logger LOG =
+        org.slf4j.LoggerFactory.getLogger(IMAPActivator.class);
 
     private WhiteboardSecretService secretService;
 
@@ -107,25 +113,19 @@ public final class IMAPActivator extends HousekeepingActivator {
     @Override
     protected Class<?>[] getNeededServices() {
         return new Class<?>[] {
-            ConfigurationService.class, CacheService.class, UserService.class, MailAccountStorageService.class, ThreadPoolService.class,
-            TimerService.class, SessiondService.class, DatabaseService.class, TextXtractService.class, EventAdmin.class };
+            ConfigurationService.class, CacheService.class, CacheEventService.class, UserService.class, MailAccountStorageService.class,
+            ThreadPoolService.class, TimerService.class, SessiondService.class, DatabaseService.class, TextXtractService.class,
+            EventAdmin.class };
     }
 
     @Override
     protected void handleUnavailability(final Class<?> clazz) {
-        /*
-         * Never stop the server even if a needed service is absent
-         */
-        if (LOG.isWarnEnabled()) {
-            LOG.warn("Absent service: " + clazz.getName());
-        }
+        LOG.warn("Absent service: {}", clazz.getName());
     }
 
     @Override
     protected void handleAvailability(final Class<?> clazz) {
-        if (LOG.isInfoEnabled()) {
-            LOG.info("Re-available service: " + clazz.getName());
-        }
+        LOG.info("Re-available service: {}", clazz.getName());
     }
 
     @Override
@@ -154,6 +154,7 @@ public final class IMAPActivator extends HousekeepingActivator {
              * Trackers
              */
             track(MailcapCommandMap.class, new MailcapServiceTracker(context));
+            track(CacheEventService.class, new ListLsubInvalidator(context));
             openTrackers();
             /*
              * Register login handler
@@ -165,10 +166,36 @@ public final class IMAPActivator extends HousekeepingActivator {
             {
                 final Dictionary<String, Object> serviceProperties = new Hashtable<String, Object>(1);
                 serviceProperties.put(EventConstants.EVENT_TOPIC, SessiondEventConstants.getAllTopics());
-                registerService(EventHandler.class, new EventHandler() {
+                final EventHandler eventHandler = new EventHandler() {
 
                     @Override
                     public void handleEvent(final Event event) {
+                        final ThreadPoolService threadPool = getService(ThreadPoolService.class);
+                        if (null == threadPool) {
+                            doHandleEvent(event);
+                        } else {
+                            final AbstractTask<Void> t = new AbstractTask<Void>() {
+
+                                @Override
+                                public Void call() throws Exception {
+                                    try {
+                                        doHandleEvent(event);
+                                    } catch (final Exception e) {
+                                        LOG.warn("Handling event {} failed.", event.getTopic(), e);
+                                    }
+                                    return null;
+                                }
+                            };
+                            threadPool.submit(t, CallerRunsBehavior.<Void> getInstance());
+                        }
+                    }
+
+                    /**
+                     * Handles given event.
+                     *
+                     * @param event The event
+                     */
+                    protected void doHandleEvent(final Event event) {
                         final String topic = event.getTopic();
                         if (SessiondEventConstants.TOPIC_REMOVE_DATA.equals(topic)) {
                             @SuppressWarnings("unchecked") final Map<String, Session> container =
@@ -213,16 +240,16 @@ public final class IMAPActivator extends HousekeepingActivator {
                         }
                     }
 
-                },
-                    serviceProperties);
+                };
+                registerService(EventHandler.class, eventHandler, serviceProperties);
             }
             {
                 final Dictionary<String, Object> serviceProperties = new Hashtable<String, Object>(1);
                 serviceProperties.put(EventConstants.EVENT_TOPIC, "com/openexchange/passwordchange");
-                registerService(EventHandler.class, new EventHandler() {
+                final EventHandler eventHandler = new EventHandler() {
 
                     @Override
-                    public void handleEvent(Event event) {
+                    public void handleEvent(final Event event) {
                         final int contextId = ((Integer) event.getProperty("com.openexchange.passwordchange.contextId")).intValue();
                         final int userId = ((Integer) event.getProperty("com.openexchange.passwordchange.userId")).intValue();
                         final Session session = (Session) event.getProperty("com.openexchange.passwordchange.session");
@@ -231,10 +258,37 @@ public final class IMAPActivator extends HousekeepingActivator {
                         ThreadableCache.dropFor(session);
                     }
 
-                }, serviceProperties);
+                };
+                registerService(EventHandler.class, eventHandler, serviceProperties);
+            }
+            {
+                final Dictionary<String, Object> serviceProperties = new Hashtable<String, Object>(1);
+                serviceProperties.put(EventConstants.EVENT_TOPIC, PushEventConstants.getAllTopics());
+                final EventHandler eventHandler = new EventHandler() {
+
+                    @Override
+                    public void handleEvent(final Event event) {
+                        if (Boolean.TRUE.equals(event.getProperty("__isRemoteEvent"))) { // Remotely received
+                            final Session session = ((Session) event.getProperty(PushEventConstants.PROPERTY_SESSION));
+                            if (null != session) {
+                                try {
+                                    final String folderId = (String) event.getProperty(PushEventConstants.PROPERTY_FOLDER);
+                                    final FullnameArgument fa = MailFolderUtility.prepareMailFolderParam(folderId);
+                                    final Boolean contentRelated = (Boolean) event.getProperty(PushEventConstants.PROPERTY_CONTENT_RELATED);
+                                    if (null == contentRelated || false == contentRelated.booleanValue()) {
+                                        ListLsubCache.clearCache(fa.getAccountId(), session);
+                                    }
+                                } catch (final Exception e) {
+                                    LOG.error("Failed to handle event: {}", event.getTopic(), e);
+                                }
+                            }
+                        }
+                    }
+                };
+                registerService(EventHandler.class, eventHandler, serviceProperties);
             }
         } catch (final Exception e) {
-            LOG.error(e.getMessage(), e);
+            LOG.error("", e);
             throw e;
         }
     }
@@ -254,7 +308,7 @@ public final class IMAPActivator extends HousekeepingActivator {
                 secretService = null;
             }
         } catch (final Exception e) {
-            LOG.error(e.getMessage(), e);
+            LOG.error("", e);
             throw e;
         }
     }
