@@ -98,12 +98,9 @@ public final class BoundaryAwareIMAPStoreContainer extends UnboundedIMAPStoreCon
         }
 
         // Try acquire a permit
-        final boolean debugEnabled = LOG.isDebugEnabled();
         final Limiter limiter = getLimiter(maxNumAuthenticated);
         if (limiter.acquire()) {
-            if (debugEnabled) {
-                LOG.debug("BoundaryAwareIMAPStoreContainer.getStore(): Acquired -- " + limiter);
-            }
+            LOG.debug("BoundaryAwareIMAPStoreContainer.getStore(): Acquired -- {}", limiter);
             return super.getStore(imapSession, login, pw);
         }
 
@@ -111,23 +108,17 @@ public final class BoundaryAwareIMAPStoreContainer extends UnboundedIMAPStoreCon
         synchronized (limiter) {
             int count = maxRetryCount;
             while (count-- > 0 && !limiter.acquire()) {
-                if (debugEnabled) {
-                    LOG.debug("BoundaryAwareIMAPStoreContainer.getStore(): W A I T I N G -- " + limiter);
-                }
+                LOG.debug("BoundaryAwareIMAPStoreContainer.getStore(): W A I T I N G -- {}", limiter);
                 limiter.wait(2000);
             }
             if (count <= 0) {
                 // Timed out -- So what...?
-                if (debugEnabled) {
-                    LOG.debug("BoundaryAwareIMAPStoreContainer.getStore(): T I M E D   O U T -- " + limiter);
-                }
+                LOG.debug("BoundaryAwareIMAPStoreContainer.getStore(): T I M E D   O U T -- {}", limiter);
                 // /final String message = "Max. number of connections exceeded. Try again later.";
                 // /throw new MessagingException(message, new com.sun.mail.iap.ConnectQuotaExceededException(message));
             }
         }
-        if (debugEnabled) {
-            LOG.debug("BoundaryAwareIMAPStoreContainer.getStore(): Acquired -- " + limiter);
-        }
+        LOG.debug("BoundaryAwareIMAPStoreContainer.getStore(): Acquired -- {}", limiter);
         return super.getStore(imapSession, login, pw);
     }
 
@@ -142,9 +133,7 @@ public final class BoundaryAwareIMAPStoreContainer extends UnboundedIMAPStoreCon
                 synchronized (tmp) {
                     tmp.release();
                     tmp.notifyAll();
-                    if (LOG.isDebugEnabled()) {
-                        LOG.debug("BoundaryAwareIMAPStoreContainer.backStore(): Released -- " + tmp);
-                    }
+                    LOG.debug("BoundaryAwareIMAPStoreContainer.backStore(): Released -- {}", tmp);
                 }
             }
         }
