@@ -53,15 +53,12 @@ import java.util.Iterator;
 import java.util.Queue;
 import java.util.concurrent.ConcurrentMap;
 import java.util.concurrent.LinkedBlockingQueue;
-import java.util.concurrent.atomic.AtomicInteger;
 import javax.mail.MessagingException;
-import org.apache.commons.logging.Log;
 import org.cliffc.high_scale_lib.NonBlockingHashMap;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.exception.OXException;
 import com.openexchange.imap.IMAPProvider;
 import com.openexchange.imap.services.Services;
-import com.openexchange.log.LogFactory;
 import com.openexchange.mail.MailExceptionCode;
 import com.openexchange.mail.Protocol;
 import com.openexchange.mail.config.MailProperties;
@@ -81,12 +78,9 @@ import com.sun.mail.imap.IMAPStore;
  */
 public final class IMAPStoreCache {
 
-    protected static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(IMAPStoreCache.class));
+    protected static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(IMAPStoreCache.class);
 
-    protected static final boolean DEBUG = LOG.isDebugEnabled();
-
-    private static final int SHRINKER_MILLIS =
-        (MailProperties.getInstance().getMailAccessCacheShrinkerSeconds() <= 0 ? 3 : MailProperties.getInstance().getMailAccessCacheShrinkerSeconds()) * 1000;
+    private static final int SHRINKER_MILLIS = (MailProperties.getInstance().getMailAccessCacheShrinkerSeconds() <= 0 ? 3 : MailProperties.getInstance().getMailAccessCacheShrinkerSeconds()) * 1000;
 
     protected static final int IDLE_MILLIS = MailProperties.getInstance().getMailAccessCacheIdleSeconds() * 1000;
 
@@ -104,7 +98,7 @@ public final class IMAPStoreCache {
         final boolean checkConnected = null == service ? false : service.getBoolProperty("com.openexchange.imap.checkConnected", false);
         Container container = null == service ? Container.getDefault() : Container.containerFor(service.getProperty("com.openexchange.imap.storeContainerType", Container.getDefault().getId()));
         if (Container.UNBOUNDED.equals(container) && (null != service && service.getIntProperty("com.openexchange.imap.maxNumConnections", 0) > 0)) {
-            LOG.warn("Property \"com.openexchange.imap.storeContainerType\" is set to \"unbounded\", but \"com.openexchange.imap.maxNumConnections\" is greater than zero. Using default container \"" + Container.getDefault().getId() + "\" instead.");
+            LOG.warn("Property \"com.openexchange.imap.storeContainerType\" is set to \"unbounded\", but \"com.openexchange.imap.maxNumConnections\" is greater than zero. Using default container \"{}\" instead.", Container.getDefault().getId());
             container = Container.getDefault();
         }
         tmp = instance = new IMAPStoreCache(checkConnected, container);
@@ -164,7 +158,7 @@ public final class IMAPStoreCache {
             try {
                 closeElapsed();
             } catch (final Exception e) {
-                LOG.error(e.getMessage(), e);
+                LOG.error("", e);
             }
         }
 
@@ -273,7 +267,7 @@ public final class IMAPStoreCache {
         /*
          * Check for a cached one
          */
-        final Key key = newKey(accountId, server, port, login);
+        final Key key = newKey(accountId, server, port, login, session.getUserId(), session.getContextId());
         /*
          * Get queue
          */
@@ -319,13 +313,14 @@ public final class IMAPStoreCache {
      * @param server The server name
      * @param port The port
      * @param login The login
+     * @param session The associated session
      * @return The container or <code>null</code>
      */
-    public IMAPStoreContainer optContainer(final int accountId, final String server, final int port, final String login) {
+    public IMAPStoreContainer optContainer(final int accountId, final String server, final int port, final String login, final Session session) {
         /*
          * Get container
          */
-        return map.get(newKey(accountId, server, port, login));
+        return map.get(newKey(accountId, server, port, login, session.getUserId(), session.getContextId()));
     }
 
     /**
@@ -346,14 +341,7 @@ public final class IMAPStoreCache {
          * Return connected IMAP store
          */
         try {
-            if (!DEBUG) {
-                return getContainer(accountId, server, port, login, session).getStore(imapSession, login, pw);
-            }
-            final long st = System.currentTimeMillis();
-            final IMAPStore store = getContainer(accountId, server, port, login, session).getStore(imapSession, login, pw);
-            final long dur = System.currentTimeMillis() - st;
-            LOG.debug("IMAPStoreCache.borrowIMAPStore() took " + dur + "msec.");
-            return store;
+            return getContainer(accountId, server, port, login, session).getStore(imapSession, login, pw);
         } catch (final InterruptedException e) {
             // Should not occur
             Thread.currentThread().interrupt();
@@ -375,8 +363,9 @@ public final class IMAPStoreCache {
      * @param server The host name of the IMAP server
      * @param port The port
      * @param login The login/user name
+     * @param session The associated session
      */
-    public void returnIMAPStore(final IMAPStore imapStore, final int accountId, final String server, final int port, final String login) {
+    public void returnIMAPStore(final IMAPStore imapStore, final int accountId, final String server, final int port, final String login, final Session session) {
         if (null == imapStore) {
             // Nothing to close
             return;
@@ -384,7 +373,7 @@ public final class IMAPStoreCache {
         /*
          * Get queue
          */
-        final IMAPStoreContainer container = map.get(newKey(accountId, server, port, login));
+        final IMAPStoreContainer container = map.get(newKey(accountId, server, port, login, session.getUserId(), session.getContextId()));
         if (null == container) {
             closeSafe(imapStore);
             return;
@@ -402,30 +391,36 @@ public final class IMAPStoreCache {
         }
     }
 
-    private static Key newKey(final int accountId, final String host, final int port, final String user) {
-        return new Key(accountId, host, port, user);
+    private static Key newKey(final int accountId, final String host, final int port, final String user, final int userId, final int contextId) {
+        return new Key(accountId, host, port, user, userId, contextId);
     }
 
-    private static final class Key {
+    static final class Key {
 
         private final int accountId;
         private final String host;
         private final int port;
         private final String user;
+        private final int userId;
+        private final int contextId;
         private final int hash;
 
-        protected Key(final int accountId, final String host, final int port, final String user) {
+        protected Key(final int accountId, final String host, final int port, final String user, final int userId, final int contextId) {
             super();
             this.accountId = accountId;
             this.host = host;
             this.port = port;
             this.user = user;
+            this.userId = userId;
+            this.contextId = contextId;
             final int prime = 31;
             int result = 1;
             result = prime * result + accountId;
             result = prime * result + ((host == null) ? 0 : host.hashCode());
             result = prime * result + port;
             result = prime * result + ((user == null) ? 0 : user.hashCode());
+            result = prime * result + userId;
+            result = prime * result + contextId;
             hash = result;
         }
 
@@ -449,6 +444,12 @@ public final class IMAPStoreCache {
             if (accountId != other.accountId) {
                 return false;
             }
+            if (userId != other.userId) {
+                return false;
+            }
+            if (contextId != other.contextId) {
+                return false;
+            }
             if (host == null) {
                 if (other.host != null) {
                     return false;
