@@ -341,7 +341,7 @@ public final class MessageInfo {
         int digit;
 
         if (i < max) {
-            digit = Character.digit(s.charAt(i++), RADIX);
+            digit = digitFor(s.charAt(i++));
             if (digit < 0) {
                 return -1;
             }
@@ -351,7 +351,7 @@ public final class MessageInfo {
             /*
              * Accumulating negatively avoids surprises near MAX_VALUE
              */
-            digit = Character.digit(s.charAt(i++), RADIX);
+            digit = digitFor(s.charAt(i++));
             if (digit < 0) {
                 return -1;
             }
@@ -367,4 +367,30 @@ public final class MessageInfo {
         return -result;
     }
 
+    private static int digitFor(final char c) {
+        switch (c) {
+        case '0':
+            return 0;
+        case '1':
+            return 1;
+        case '2':
+            return 2;
+        case '3':
+            return 3;
+        case '4':
+            return 4;
+        case '5':
+            return 5;
+        case '6':
+            return 6;
+        case '7':
+            return 7;
+        case '8':
+            return 8;
+        case '9':
+            return 9;
+        default:
+            return -1;
+        }
+    }
 }
